@@ -52,6 +52,7 @@
 #define BROWSE_FLAGS          (GRL_RESOLVE_FAST_ONLY | GRL_RESOLVE_IDLE_RELAY)
 #define PAGE_SIZE             50
 #define SCROLL_GET_MORE_LIMIT 0.8
+#define MAX_DURATION          5
 
 /* casts are to shut gcc up */
 static const GtkTargetEntry target_table[] = {
@@ -116,6 +117,8 @@ struct _TotemGriloPrivate {
 	/* Selection toolbar */
 	GtkWidget *selection_bar;
 	GtkWidget *selection_revealer;
+
+	GCancellable *thumbnail_cancellable;
 };
 
 enum {
@@ -254,7 +257,7 @@ source_is_recent (GrlSource *source)
 }
 
 static gboolean
-source_is_adult (GrlSource *source)
+source_is_forbidden (GrlSource *source)
 {
 	const char **tags;
 
@@ -262,7 +265,8 @@ source_is_adult (GrlSource *source)
 	if (!tags)
 		return FALSE;
 
-	return strv_has_prefix (tags, "adult");
+	return strv_has_prefix (tags, "adult") ||
+		strv_has_prefix (tags, "torrent");
 }
 
 static gchar *
@@ -436,8 +440,7 @@ set_thumbnail_async (TotemGrilo   *self,
 	thumb_data->model = g_object_ref (model);
 	thumb_data->reference = gtk_tree_row_reference_new (model, path);
 
-	//FIXME cancellable?
-	totem_grilo_get_thumbnail (object, NULL, get_thumbnail_cb, thumb_data);
+	totem_grilo_get_thumbnail (object, self->priv->thumbnail_cancellable, get_thumbnail_cb, thumb_data);
 }
 
 static gboolean
@@ -738,6 +741,10 @@ browse (TotemGrilo   *self,
 	}
 	if (grl_caps_get_type_filter (caps) & GRL_TYPE_FILTER_VIDEO)
 		grl_operation_options_set_type_filter (default_options, GRL_TYPE_FILTER_VIDEO);
+	if (grl_caps_is_key_range_filter (caps, GRL_METADATA_KEY_DURATION))
+		grl_operation_options_set_key_range_filter (default_options,
+							    GRL_METADATA_KEY_DURATION, MAX_DURATION, NULL,
+							    NULL);
 
 	bud = g_slice_new0 (BrowseUserData);
 	bud->totem_grilo = g_object_ref (self);
@@ -840,6 +847,9 @@ get_search_options (TotemGrilo *self)
 	grl_operation_options_set_skip (default_options, self->priv->search_page * PAGE_SIZE);
 	grl_operation_options_set_count (default_options, PAGE_SIZE);
 	grl_operation_options_set_type_filter (default_options, GRL_TYPE_FILTER_VIDEO);
+	grl_operation_options_set_key_range_filter (default_options,
+						    GRL_METADATA_KEY_DURATION, MAX_DURATION, NULL,
+						    NULL);
 
 	/* And now remove all the unsupported filters and options */
 	grl_operation_options_obey_caps (default_options,
@@ -1234,7 +1244,7 @@ source_added_cb (GrlRegistry *registry,
 	const char *id;
 
 	if (source_is_blacklisted (source) ||
-	    source_is_adult (source) ||
+	    source_is_forbidden (source) ||
 	    !(grl_source_get_supported_media (source) & GRL_MEDIA_TYPE_VIDEO)) {
 		grl_registry_unregister_source (registry,
 		                                source,
@@ -2444,6 +2454,9 @@ totem_grilo_finalize (GObject *object)
 		self->priv->thumbnail_update_id = 0;
 	}
 
+	g_cancellable_cancel (self->priv->thumbnail_cancellable);
+	g_clear_object (&self->priv->thumbnail_cancellable);
+
 	registry = grl_registry_get_default ();
 	g_signal_handlers_disconnect_by_func (registry, source_added_cb, self);
 	g_signal_handlers_disconnect_by_func (registry, source_removed_cb, self);
@@ -2473,6 +2486,8 @@ totem_grilo_finalize (GObject *object)
 void
 totem_grilo_start (TotemGrilo *self)
 {
+	totem_grilo_resume_icon_thumbnailing ();
+
 	if (self->priv->plugins_loaded)
 		return;
 
@@ -2482,6 +2497,12 @@ totem_grilo_start (TotemGrilo *self)
 	self->priv->plugins_loaded = TRUE;
 }
 
+void
+totem_grilo_pause (TotemGrilo *self)
+{
+	totem_grilo_pause_icon_thumbnailing ();
+}
+
 static void
 totem_grilo_constructed (GObject *object)
 {
@@ -2724,6 +2745,7 @@ totem_grilo_init (TotemGrilo *self)
 	self->priv = totem_grilo_get_instance_private (self);
 	priv = self->priv;
 
+	priv->thumbnail_cancellable = g_cancellable_new ();
 	priv->metadata_keys = grl_metadata_key_list_new (GRL_METADATA_KEY_ARTIST,
 							 GRL_METADATA_KEY_AUTHOR,
 							 GRL_METADATA_KEY_DURATION,
@@ -2735,6 +2757,7 @@ totem_grilo_init (TotemGrilo *self)
 							 GRL_METADATA_KEY_SHOW,
 							 GRL_METADATA_KEY_SEASON,
 							 GRL_METADATA_KEY_EPISODE,
+							 GRL_METADATA_KEY_TITLE_FROM_FILENAME,
 							 NULL);
 
 	gtk_widget_init_template (GTK_WIDGET (self));
