@@ -46,7 +46,6 @@ option_version_cb (const gchar *option_name,
 }
 
 const GOptionEntry all_options[] = {
-	{"debug", '\0', 0, G_OPTION_ARG_NONE, &optionstate.debug, N_("Enable debug"), NULL},
 	{"play-pause", '\0', 0, G_OPTION_ARG_NONE, &optionstate.playpause, N_("Play/Pause"), NULL},
 	{"play", '\0', 0, G_OPTION_ARG_NONE, &optionstate.play, N_("Play"), NULL},
 	{"pause", '\0', 0, G_OPTION_ARG_NONE, &optionstate.pause, N_("Pause"), NULL},
@@ -62,43 +61,20 @@ const GOptionEntry all_options[] = {
 	{"enqueue", '\0', 0, G_OPTION_ARG_NONE, &optionstate.enqueue, N_("Enqueue"), NULL},
 	{"replace", '\0', 0, G_OPTION_ARG_NONE, &optionstate.replace, N_("Replace"), NULL},
 	{"seek", '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_INT64, &optionstate.seek, N_("Seek"), NULL},
-	{ "version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
+	{"version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL},
 	{G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &optionstate.filenames, N_("Movies to play"), NULL},
 	{NULL} /* end the list */
 };
 
-GOptionContext *
-totem_options_get_context (void)
+static void
+totem_send_remote_command (Totem              *totem,
+			   TotemRemoteCommand  action,
+			   const char         *url)
 {
-	GOptionContext *context;
-	GOptionGroup *baconoptiongroup;
+	GVariant *variant;
 
-	context = g_option_context_new (N_("- Play movies and songs"));
-	baconoptiongroup = bacon_video_widget_get_option_group ();
-	if (baconoptiongroup == NULL) {
-		g_warning ("Clutter or GTK+ failed to initialise properly");
-		g_option_context_free (context);
-		return NULL;
-	}
-	g_option_context_add_main_entries (context, all_options, GETTEXT_PACKAGE);
-	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-	g_option_context_add_group (context, baconoptiongroup);
-
-	g_option_context_add_group (context, gtk_get_option_group (FALSE));
-
-	return context;
-}
-
-void
-totem_options_process_early (Totem *totem, const TotemCmdLineOptions* options)
-{
-	if (options->quit) {
-		/* If --quit is one of the commands, just quit */
-		gdk_notify_startup_complete ();
-		exit (0);
-	}
-
-	g_settings_set_boolean (totem->settings, "debug", options->debug);
+	variant = g_variant_new ("(is)", action, url ? url : "");
+	g_action_group_activate_action (G_ACTION_GROUP (totem), "remote-command", variant);
 }
 
 void
@@ -114,7 +90,7 @@ totem_options_process_for_server (Totem                     *totem,
 
 	/* Are we quitting ? */
 	if (options->quit) {
-		totem_object_remote_command (totem, TOTEM_REMOTE_COMMAND_QUIT, NULL);
+		totem_send_remote_command (totem, TOTEM_REMOTE_COMMAND_QUIT, NULL);
 		return;
 	}
 
@@ -135,7 +111,7 @@ totem_options_process_for_server (Totem                     *totem,
 		filename = options->filenames[i];
 		full_path = totem_create_full_path (filename);
 
-		totem_object_remote_command (totem, action, full_path ? full_path : filename);
+		totem_send_remote_command (totem, action, full_path ? full_path : filename);
 
 		g_free (full_path);
 
@@ -202,14 +178,15 @@ totem_options_process_for_server (Totem                     *totem,
 	}
 
 	/* No commands, no files, show ourselves */
-	if (commands == NULL) {
-		totem_object_remote_command (totem, TOTEM_REMOTE_COMMAND_SHOW, NULL);
+	if (commands == NULL &&
+	    !(g_application_get_flags (G_APPLICATION (totem)) & G_APPLICATION_IS_SERVICE)) {
+		totem_send_remote_command (totem, TOTEM_REMOTE_COMMAND_SHOW, NULL);
 		return;
 	}
 
 	/* Send commands */
 	for (l = commands; l != NULL; l = l->next) {
-		totem_object_remote_command (totem, GPOINTER_TO_INT (l->data), NULL);
+		totem_send_remote_command (totem, GPOINTER_TO_INT (l->data), NULL);
 	}
 
 	g_list_free (commands);
