@@ -31,7 +31,6 @@ G_BEGIN_DECLS
 
 /* Stores the state of the command line options */
 typedef struct {
-	gboolean debug;
 	gboolean playpause;
 	gboolean play;
 	gboolean pause;
@@ -55,11 +54,6 @@ extern const GOptionEntry all_options[];
 extern TotemCmdLineOptions optionstate;
 
 void totem_options_register_remote_commands (Totem *totem);
-GOptionContext *totem_options_get_context (void);
-void totem_options_process_early (Totem *totem,
-				  const TotemCmdLineOptions* options);
-void totem_options_process_late (Totem *totem, 
-				 const TotemCmdLineOptions* options);
 void totem_options_process_for_server (Totem *totem,
 				       const TotemCmdLineOptions* options);
 
